==> owncloud-tasks_0.7.1.orig.tar.gz: tasks-0.7.1/l10n/es.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Tareas",
    "Due yesterday" : "Para ayer",
    "Due today" : "Para hoy",
    "Due tomorrow" : "Para mañana",
    "Due on" : "Para el",
    "Started yesterday" : "Empezado ayer",
    "Starts today" : "Empieza hoy",
    "Starts tomorrow" : "Empieza mañana",
    "Started on" : "Empezado el",
    "Starts on" : "Empieza el",
    "[Remind me yesterday at ]HH:mm" : "[Recordármelo mañana a las ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Recordármelo hoy a las ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Recordármelo mañana a las ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Recordármelo el ]MMM DD, YYYY,[ a las ]HH:mm",
    "Yesterday" : "Ayer",
    "Today" : "Hoy",
    "Tomorrow" : "Mañana",
    "in %s" : "en %s",
    "%s ago" : "Hace %s",
    "seconds" : "segundos",
    "a minute" : "un minuto",
    "%d minutes" : "%d minutos",
    "an hour" : "una hora",
    "%d hours" : "%d horas",
    "a day" : "un día",
    "%d days" : "%d días",
    "a month" : "un mes",
    "%d months" : "%d meses",
    "a year" : "un año",
    "%d years" : "%d años",
    "Hours" : "Horas",
    "Minutes" : "Minutos",
    "week" : "semana",
    "weeks" : "semanas",
    "day" : "día",
    "days" : "días",
    "hour" : "hora",
    "hours" : "horas",
    "minute" : "minuto",
    "minutes" : "minutos",
    "second" : "segundo",
    "before beginning" : "antes del comienzo",
    "after beginning" : "después del comienzo",
    "before end" : "antes del final",
    "after end" : "después del final",
    "Comment" : "Comentario",
    "Add a comment" : "Agregar un comentario",
    "This will delete the Calendar \"%s\" and all of its entries." : "Esto eliminará el calendario \"%s\" y todas sus entradas.",
    "The name \"%s\" is already used." : "El nombre \"%s\" ya está en uso.",
    "An empty name is not allowed." : "No se puede dejar el nombre en blanco.",
    "Hidden" : "Oculto",
    "Visible" : "Visible",
    "Automatic" : "Automático",
    "Sunday" : "Domingo",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Add an important item in \"%s\"..." : "Agregar un elemento importante en \"%s\"...",
    "Add an item due today in \"%s\"..." : "Agregar un elemento para hoy en \"%s\"...",
    "Add an item in \"%s\"..." : "Agregar un elemento en \"%s\"...",
    "Add a current item in \"%s\"..." : "Agregar un elemento actual en \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n tarea completada","%n tareas completadas"],
    "Set due date" : "Fijar fecha límite",
    "%s %% completed" : "%s %% completado",
    "priority %s: " : "prioridad %s: ",
    "high" : "alta",
    "medium" : "media",
    "low" : "baja",
    "no priority assigned" : "sin prioridad asignada",
    "Remind me" : "Recordarme",
    "at the end" : "al final",
    "at the beginning" : "al principio",
    "Set start date" : "Establecer fecha de inicio",
    "Important" : "Importante",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Actual",
    "Completed" : "Completada",
    "rename" : "renombrar",
    "delete" : "borrar",
    "Add List..." : "Agregar lista...",
    "New List" : "Nueva lista",
    "Settings" : "Ajustes",
    "Start of week" : "Primer día de la semana",
    "Visibility of Smart Collections" : "Visibilidad de las colecciones inteligentes",
    "Load remaining completed tasks." : "Carga restante de tareas completadas.",
    "(New category)" : "(Nueva categoría)",
    "Select categories..." : "Seleccione categoría...",
    "Loading the task..." : "Cargando tareas...",
    "Task not found!" : "¡Tarea no encontrada!"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-tasks_0.8.1.orig.tar.gz: tasks-0.8.1/l10n/es.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Tareas",
    "Tasks app is unavailable because the calendar is not installed" : "Las tareas de la aplicación no están disponibles debido a que el calendario no está instalado",
    "Due yesterday" : "Para ayer",
    "Due today" : "Para hoy",
    "Due tomorrow" : "Para mañana",
    "Due on" : "Para el",
    "Started yesterday" : "Empezado ayer",
    "Starts today" : "Empieza hoy",
    "Starts tomorrow" : "Empieza mañana",
    "Started on" : "Empezado el",
    "Starts on" : "Empieza el",
    "[Remind me yesterday at ]HH:mm" : "[Recordármelo mañana a las ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Recordármelo hoy a las ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Recordármelo mañana a las ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Recordármelo el ]MMM DD, YYYY,[ a las ]HH:mm",
    "Yesterday" : "Ayer",
    "Today" : "Hoy",
    "Tomorrow" : "Mañana",
    "in %s" : "en %s",
    "%s ago" : "Hace %s",
    "seconds" : "segundos",
    "a minute" : "un minuto",
    "%d minutes" : "%d minutos",
    "an hour" : "una hora",
    "%d hours" : "%d horas",
    "a day" : "un día",
    "%d days" : "%d días",
    "a month" : "un mes",
    "%d months" : "%d meses",
    "a year" : "un año",
    "%d years" : "%d años",
    "Hours" : "Horas",
    "Minutes" : "Minutos",
    "week" : "semana",
    "weeks" : "semanas",
    "day" : "día",
    "days" : "días",
    "hour" : "hora",
    "hours" : "horas",
    "minute" : "minuto",
    "minutes" : "minutos",
    "second" : "segundo",
    "before beginning" : "antes del comienzo",
    "after beginning" : "después del comienzo",
    "before end" : "antes del final",
    "after end" : "después del final",
    "Comment" : "Comentario",
    "Add a comment" : "Agregar un comentario",
    "This will delete the Calendar \"%s\" and all of its entries." : "Esto eliminará el calendario \"%s\" y todas sus entradas.",
    "The name \"%s\" is already used." : "El nombre \"%s\" ya está en uso.",
    "An empty name is not allowed." : "No se puede dejar el nombre en blanco.",
    "Hidden" : "Oculto",
    "Visible" : "Visible",
    "Automatic" : "Automático",
    "Sunday" : "Domingo",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Add an important item in \"%s\"..." : "Agregar un elemento importante en \"%s\"...",
    "Add an item due today in \"%s\"..." : "Agregar un elemento para hoy en \"%s\"...",
    "Add an item in \"%s\"..." : "Agregar un elemento en \"%s\"...",
    "Add a current item in \"%s\"..." : "Agregar un elemento actual en \"%s\"...",
    "Add a subtask to \"%s\"..." : "Añadir subtarea a \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n tarea completada","%n tareas completadas"],
    "Set due date" : "Fijar fecha límite",
    "%s %% completed" : "%s %% completado",
    "priority %s: " : "prioridad %s: ",
    "high" : "alta",
    "medium" : "media",
    "low" : "baja",
    "no priority assigned" : "sin prioridad asignada",
    "Remind me" : "Recordarme",
    "at the end" : "al final",
    "at the beginning" : "al principio",
    "Set start date" : "Establecer fecha de inicio",
    "Important" : "Importante",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Actual",
    "Completed" : "Completada",
    "rename" : "renombrar",
    "delete" : "borrar",
    "Add List..." : "Agregar lista...",
    "New List" : "Nueva lista",
    "Settings" : "Ajustes",
    "Start of week" : "Primer día de la semana",
    "Visibility of Smart Collections" : "Visibilidad de las colecciones inteligentes",
    "Load remaining completed tasks." : "Carga restante de tareas completadas.",
    "(New category)" : "(Nueva categoría)",
    "Select categories..." : "Seleccione categoría...",
    "Loading the task..." : "Cargando tareas...",
    "Task not found!" : "¡Tarea no encontrada!",
    "add a subtask to" : "Añadir subtarea a"
},
"nplurals=2; plural=(n != 1);");
